<?php
/**
 * The template for displaying comments
 *
 * The area of the page that contains both current comments
 * and the comment form.
 *
 * @package growth
 */

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}
?>
<div id="comments" class="comments-area col-xs-12">
    <?php
    /*---------------------------------------------------------------------------------------
    If comments are closed and there are comments, let's leave a little note, shall we?
    ----------------------------------------------------------------------------------------*/
    if ( ! comments_open() && get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
    ?>
    <p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'growth' ); ?></p>
    <?php endif;
    if( is_user_logged_in() ){
        $column = 'col-xs-12';
    }else{
        $column = 'col-xs-12 col-md-6';
    }
    $commenter             = wp_get_current_commenter();
    $req                   = get_option( 'require_name_email' );
    $required_text         = sprintf( ' ' . __( 'Required fiels are marked %s', 'growth' ), '<span class="required">*</span>' );
    $aria_req              = ( $req ? " aria-required='true'" : '' );
    $consent               = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';
    $growth_comment_fields =  array(        
        'author' => '<div class="'.esc_attr($column).'"><p class="comment-form-author"><label for="author" class="icon"><i class="far fa-user"></i></label><input id="author" name="author" type="text" value="'.esc_attr( $commenter['comment_author'] ).'" size="30" '. $aria_req .' '. $aria_req .' placeholder="'.esc_attr__('Full name','growth').'"></p>',
        'email' => '<p class="comment-form-email"><label for="email" class="icon"><i class="far fa-envelope"></i></label><input id="email" name="email" type="email" size="30" value="'.esc_attr( $commenter['comment_author_email'] ).'" '. $aria_req .' placeholder="'.esc_attr__('Email address','growth').'" ></p></div>',
        'url' => '',
        'cookies' => '<div class="col-xs-12"><p class="comment-form-cookies-consent"><input id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />' . '<label for="wp-comment-cookies-consent">' . esc_html__( 'Save my name, email, and website in this browser for the next time I comment.', 'growth' ) . '</label></p></div>'
    );            
    comment_form( array(
        'fields' => apply_filters( 'comment_form_default_fields', $growth_comment_fields ),
        'comment_notes_before' => '<p class="comment-notes col-xs-12">' . __( 'Your email address will not be published.','growth' ) . ( $req ? $required_text : '' ) .'</p>',
        'comment_field' => '<div class="'.esc_attr($column).' pull-right"><p class="comment-form-comment"><label for="comment" class="icon"><i class="fas fa-pencil-alt"></i></label><textarea id="comment" name="comment" cols="50" rows="4" required="required" placeholder="'.esc_attr__('Start the opinion','growth').'"></textarea></p></div>',
        'class_submit' => 'bttn-1 submit-button',
        'class_form' => 'comment-form row',
        'submit_field' => '<p class="form-submit col-xs-12">%1$s %2$s</p>',
        'logged_in_as' => '<p class="logged-in-as col-xs-12">'. esc_html__( 'Logged in as ','growth' ) .sprintf( '<a href="%1$s">%2$s</a>. <a href="%3$s" title="'.esc_attr__('Log out of this account','growth').'">'.esc_html__( 'Log out?','growth' ).'</a>' ,admin_url( 'profile.php' ),$user_identity,wp_logout_url( apply_filters( 'the_permalink', get_permalink( )))) . '</p>',
        'title_reply' => esc_html__( 'Leave an Opinion', 'growth' )
    ) );
    
    if ( have_comments() ) : ?>
    <div class="comment-list-area">
        <h3 class="comments-title">
            <?php
                $comments_number = get_comments_number();
                if ( '1' === $comments_number ) {
                    /* translators: %s: post title */
                    printf( _x( 'Current Opinion on &ldquo;%s&rdquo;', 'comments title', 'growth' ), get_the_title() );
                } else {
                    printf(
                        /* translators: 1: number of comments, 2: post title */
                        _nx(
                            '%1$s Current Opinions',
                            '%1$s Current Opinions',
                            $comments_number,
                            'comments title',
                            'growth'
                        ),
                        number_format_i18n( $comments_number ),
                        get_the_title()
                    );
                }
            ?>
        </h3>
        <ol class="comment-list">
            <?php
                wp_list_comments(
                    array(
                        'style'       => 'ul+',
                        'short_ping'  => true,
                        'avatar_size' => 100
                    )
                );
            ?>
        </ol>
        <?php 
            $paginet = array(
                'prev_text'          => '<i class="far fa-angle-left"></i>',
                'next_text'          => '<i class="far fa-angle-right"></i>',
                'screen_reader_text' => ' ',
                'type'               => 'array',
                'show_all'           => true,
            );
            the_comments_pagination( $paginet );
        ?>
    </div>       
    <?php endif; ?>    
</div>