<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */
if ( ! class_exists( 'Redux' ) ) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "growth_opt";

/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */
$theme = wp_get_theme(); // For use with some settings. Not necessary.
$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get( 'Name' ),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get( 'Version' ),
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => __( 'Growth Options', 'growth' ),
    'page_title'           => __( 'Growth Options', 'growth' ),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => false,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    // OPTIONAL -> Give you extra features
    'page_priority'        => 30,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'growth_opt',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.
    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.
    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.
    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )
);

Redux::setArgs( $opt_name, $args );
/*
 * ---> END ARGUMENTS
 */

Redux::setSection( $opt_name, array(
    'title'            => __( 'Global Option', 'growth' ),
    'id'               => 'global_setting',
    'desc'             => __( 'All Global Theme Settings.', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-home'
) );
Redux::setSection( $opt_name, array(
    'title'      => __( 'Animated Loader', 'growth' ),
    'id'         => 'loader_option',
    'subsection' => true,
    'fields'     => array(
         array(
            'id'       => 'loader_switch',
            'type'     => 'switch',
            'title'    => __( 'Show Loader?', 'growth' ),
            'subtitle' => __( 'Turn on to display preloader.', 'growth' ),
            'default'  => true,
        ),
        array(
            'id'       => 'loader_color',
            'type'     => 'color',
            'title'    => __( 'Loader Color', 'growth' ),
            'subtitle' => __( 'Pick a loader color for the theme (default: #FFC576).', 'growth' ),
            'default'  => '#ffc576',
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'ScrollUp Button', 'growth' ),
    'id'         => 'scrollUp_option',
    'subsection' => true,
    'fields'     => array(
         array(
            'id'       => 'scrollUp_switch',
            'type'     => 'switch',
            'title'    => __( 'Button Switch.', 'growth' ),
            'subtitle' => __( 'Turn on to display scrollup button.', 'growth' ),
            'default'  => true,
        )
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Custom CSS', 'growth' ),
    'id'         => 'custom_css_options',
    'subsection' => true,
    'fields'     => array(
         array(
            'id'       => 'custom_css',
            'type'     => 'ace_editor',
            'title'    => __( 'Custom CSS Code', 'growth' ),
            'subtitle' => __( 'Paste your CSS code here.', 'growth' ),
            'mode'     => 'css',
            'theme'    => 'monokai'
        ),
    )
) );
Redux::setSection( $opt_name, array(
    'title'            => __( 'Typography', 'growth' ),
    'id'               => 'all_typography',
    'desc'             => __( 'This tab contains general typography options. Additional typography options for specific areas can be found within other tabs. Example: For menu typography options go to the menu tab.', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-home'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Body Typography', 'growth' ),
    'id'         => 'general_typography',
    'subsection' => true,
    'fields'     => array(    
        array(
            'id'   => 'body_typo_notice',
            'type' => 'info',
            'desc' => __('This tab contains general typography options. Additional typography options for specific areas can be found within other tabs. Example: For menu typography options go to the menu tab.', 'growth')
        ),
        array(
            'id'          => 'body_typography',
            'type'        => 'typography',
            'title'       => __( 'Body Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> false,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'body' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'       => 'px',
            // Defaults to px
            'subtitle'    => __( 'Typography option with each property can be called individually.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '400',
                'google'      => true,
                'font-size'   => '16px',
            ),  
        ),           
        array(
            'id'       => 'link_color',
            'type'     => 'color',
            'output'   => array( 'a' ),
            'title'    => __( 'Link Color', 'growth' ),
            'subtitle' => __( 'Controls the color of all text links.', 'growth' ),
            'default'  => '#ffffff',
        ),      
        array(
            'id'       => 'hover_link_color',
            'type'     => 'color',
            'output'   => array( 'a:hover' ),
            'title'    => __( 'Link Hover Color', 'growth' ),
            'subtitle' => __( 'Controls the color of all text links hover.', 'growth' ),
            'default'  => '#FFC576',
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Heading Typography', 'growth' ),
    'id'         => 'heading_typography',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'h1_typography',
            'type'        => 'typography',
            'title'       => __( 'H1 Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'h1' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'       => array( 'em', 'px', '%' ), 
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for all H1 Heading.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '39px',
            ),  
        ),           
        array(
            'id'          => 'h2_typography',
            'type'        => 'typography',
            'title'       => __( 'H2 Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'h2' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for all H2 Heading.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '31px',
            ),  
        ),            
        array(
            'id'             => 'h3_typography',
            'type'           => 'typography',
            'title'          => __( 'H3 Typography', 'growth' ),
            'google'         => true,
            'font-backup'    => false,
            'font-style'     => false,
            'subsets'        => false,
            //'font-size'    => false,
            'line-height'    => false,
            //'word-spacing' => true,  // Defaults to false
            'letter-spacing' => true,  // Defaults to false
            //'color'        => false,
            //'preview'      => false, // Disable the previewer
            'all_styles'     => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'         => array( 'h3' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'       => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'       => __( 'These settings control the typography for all H3 Heading.', 'growth' ),
            'default'        => array(
                'color'       => '#ffffff',
                'font-weight' => '600',
                'google'      => true,
                'font-size'   => '25px',
            ),  
        ),         
        array(
            'id'          => 'h4_typography',
            'type'        => 'typography',
            'title'       => __( 'H4 Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'h4' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for all H4 Heading.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '20px',
            ),  
        ),            
        array(
            'id'          => 'h5_typography',
            'type'        => 'typography',
            'title'       => __( 'H5 Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'h5' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for all H5 Heading.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '16px',
            ),  
        ),             
        array(
            'id'          => 'h6_typography',
            'type'        => 'typography',
            'title'       => __( 'H6 Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( 'h6' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for all H6 Heading.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '12px'
            ),  
        ),             
        array(
            'id'          => 'post_title_typography',
            'type'        => 'typography',
            'title'       => __( 'Post Title Typography', 'growth' ),
            'google'      => true,
            'font-backup' => false,
            'font-style'    => false,
            'subsets'       => false,
            //'font-size'     => false,
            'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( '.post-title' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'          => array( 'em', 'px', '%' ),
            // Defaults to px
            'subtitle'    => __( 'These settings control the typography for Post Title.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '24px'
            ),  
        ),
    )
) );
Redux::setSection( $opt_name, array(
    'title'            => __( 'Main Menu', 'growth' ),
    'id'               => 'mainmenu_area',
    'desc'             => __( 'These are mainmenu content fields!', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-align-left'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Menu Options', 'growth' ),
    'id'         => 'menu_options',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'menu_width',
            'type'     => 'spinner', 
            'title'    => __('Menu Width', 'growth'),
            'desc'     => __('Controls the overall menu width. Enter value including any valid CSS unit, ex: 1170px.', 'growth'),
            'default'  => '1170',
            'min'      => '320',
            'step'     => '10',
            'max'      => '1920'
        ),
         array(
            'id'       => 'transparent_menu',
            'type'     => 'switch',
            'title'    => __( 'Transparent Menu', 'growth' ),
            'subtitle' => __( 'Turn on to enable a transparent menu.', 'growth' ),
            'default'  => true,
        ),
         array(
            'id'       => 'sticky_menu',
            'type'     => 'switch',
            'title'    => __( 'Sticky Menu', 'growth' ),
            'subtitle' => __( 'Turn on to enable a sticky menu.', 'growth' ),
            'default'  => false,
        ),
        array(
            'id'       => 'menu_button',
            'type'     => 'multi_text',
            'title'    => __( 'Menu Buttons', 'growth' ),
            'subtitle' => __( 'To set multiple menu button.', 'growth' ),
            'desc'     => __( 'To create a new button. Please use this markup ( &lt;a class="button-sm" href="#" &gt;Support&lt;/a&gt; ). and use custom css field for style.', 'growth' ),
            'add_text' => 'Add Button',
            'show_empty' => true,
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Normal Menu', 'growth' ),
    'id'         => 'normal_menu_style',
    'subsection' => true,
    'fields'     => array(  
            array(
                'id'             => 'normal_menu_offset',
                'type'           => 'spacing',
                'output'   => array( '.mainmenu-area' ),
                // An array of CSS selectors to apply this font style to
                'mode'           => 'padding',
                // absolute, padding, margin, defaults to padding
                'all'            => false,
                // Have one field that applies to all
                //'top'           => false,     // Disable the top
                //'right'         => false,     // Disable the right
                //'bottom'        => false,     // Disable the bottom
                //'left'          => false,     // Disable the left
                'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',    // Allow users to select any type of unit
                //'display_units' => 'false',   // Set to false to hide the units if the units are specified
                'title'          => __( 'Menu Offset', 'growth' ),
                'desc'           => __( 'Controls the offset of the boxed background.', 'growth' ),
                'default'        => array(
                    'padding-top'    => '20px',
                    'padding-bottom' => '20px',
                    'padding-left' => '0',
                    'padding-right' => '0'
                )
            ),
            array(
                'id'       => 'normal_menu_bg',
                'type'     => 'background',
                'title'    => __( 'Menu Background', 'growth' ),
                'subtitle' => __( 'Pick a background color for the menu (default: #1F2235).', 'growth' ),
                'default'  => '#1F2235',
                'output'   => array( '.mainmenu-area' ),
                'required' => array('transparent_menu','=',false)
            ),          
            array(
                'id'          => 'normal_logo_typography',
                'type'        => 'typography',
                'title'       => __( 'Logo Typography', 'growth' ),
                'google'      => true,
                'font-backup' => false,
                'font-style'    => false,
                'subsets'       => false,
                //'font-size'     => false,
                'line-height'   => false,
                //'word-spacing'  => true,  // Defaults to false
                'letter-spacing'=> false,  // Defaults to false
                //'color'         => false,
                //'preview'       => false, // Disable the previewer
                'all_styles'  => true,
                // Enable all Google Font style/weight variations to be added to the page
                'output'      => array( '.site-branding' ),
                // An array of CSS selectors to apply this font style to dynamically
                'compiler'    => array( 'page-subtitle-compiler' ),
                // An array of CSS selectors to apply this font style to dynamically
                'units'       => 'px',
                // Defaults to px
                'subtitle'    => __( 'Typography option with each property can be called individually.', 'growth' ),
                'default'     => array(
                    'color'       => '#ffffff',
                    'font-weight'  => '600',
                    'google'      => true,
                    'font-size'   => '36px',
                ),  
            ),             
            array(
                'id'          => 'normal_menu_typography',
                'type'        => 'typography',
                'title'       => __( 'Menu Typography', 'growth' ),
                //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
                'google'      => true,
                // Disable google fonts. Won't work if you haven't defined your google api key
                'font-backup' => false,
                // Select a backup non-google font in addition to a google font
                'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
                'subsets'       => false, // Only appears if google is true and subsets not set to false
                //'font-size'     => false,
                //'line-height'   => false,
                //'word-spacing'  => true,  // Defaults to false
                'letter-spacing'=> true,  // Defaults to false
                //'color'         => false,
                //'preview'       => false, // Disable the previewer
                'all_styles'  => true,
                // Enable all Google Font style/weight variations to be added to the page
                'output'      => array( '.primary-menu ul.nav li a' ),
                // An array of CSS selectors to apply this font style to dynamically
                'compiler'    => array( 'page-subtitle-compiler' ),
                // An array of CSS selectors to apply this font style to dynamically
                'units'       => 'px',
                // Defaults to px
                'default'     => array(
                    'color'       => '#ffffff',
                    'font-weight'  => '600',
                    'google'      => true,
                    'font-size'   => '14px',
                    'line-height' => '30px'
                ),  
            ),           
            array(
                'id'       => 'normal_menu_hover_color',
                'type'     => 'color',
                'output'   => array( '.primary-menu ul.nav li:hover > a','.primary-menu ul.nav li.active > a','.primary-menu ul.nav li.current-menu-item > a' ),
                'title'    => __( 'Active/Hover Color', 'growth' ),
                'subtitle' => __( 'Pick a menu Hover/Active color (default: #ffc576).', 'growth' ),
                'default'  => '#FFC576',
            ),         
            array(
                'id'       => 'menu_active_color',
                'type'     => 'color',
                'output'   => array( '.primary-menu ul.nav > li > a:before' ),
                'title'    => __( 'Menu Bar Color', 'growth' ),
                'subtitle' => __( 'Pick a menu active angle color: (default: #FFC576).', 'growth' ),
                'default'  => '#FFC576',
            ),
        ),        
    )
);
Redux::setSection( $opt_name, array(
    'title'      => __( 'Sticky Menu', 'growth' ),
    'id'         => 'sticky_menu_style',
    'subsection' => true,
    'fields'     => array(  
            array(
                'id'             => 'sticky_menu_offset',
                'type'           => 'spacing',
                'output'   => array( '.mainmenu-area.affix' ),
                // An array of CSS selectors to apply this font style to
                'mode'           => 'padding',
                // absolute, padding, margin, defaults to padding
                'all'            => false,
                // Have one field that applies to all
                //'top'           => false,     // Disable the top
                //'right'         => false,     // Disable the right
                //'bottom'        => false,     // Disable the bottom
                //'left'          => false,     // Disable the left
                'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
                'units_extended' => 'true',    // Allow users to select any type of unit
                //'display_units' => 'false',   // Set to false to hide the units if the units are specified
                'title'          => __( 'Menu Offset', 'growth' ),
                'desc'           => __( 'Controls the offset of the boxed background.', 'growth' ),
                'default'        => array(
                    'padding-top'    => '20px',
                    'padding-bottom' => '20px',
                    'padding-left' => '0',
                    'padding-right' => '0'
                )
            ),
            array(
                'id'       => 'sticky_menu_bg',
                'type'     => 'background',
                'title'    => __( 'Menu Background', 'growth' ),
                'subtitle' => __( 'Pick a background color for the menu (default: #1F2235).', 'growth' ),
                'default'  => '#1F2235',
                'output'   => array( '.mainmenu-area.affix' ),
            ),          
            array(
                'id'       => 'sticky_menu_color',
                'type'     => 'color',
                'output'   => array( '.affix .primary-menu ul.nav li > a' ),
                'title'    => __( 'Menu Color', 'growth' ),
                'subtitle' => __( 'Pick a menu color (default: #ffffff).', 'growth' ),
                'default'  => '#ffffff',
            ),           
            array(
                'id'       => 'sticky_menu_hover_color',
                'type'     => 'color',
                'output'   => array( '.affix .primary-menu ul.nav li:hover > a','.affix .primary-menu ul.nav li.active > a','.affix .primary-menu ul.nav li.current-menu-item > a' ),
                'title'    => __( 'Menu Active/Hover Color', 'growth' ),
                'subtitle' => __( 'Pick a menu Hover/Active color (default: #ffc576).', 'growth' ),
                'default'  => '#FFC576',
            ),         
            array(
                'id'       => 'sticky_menu_active_color',
                'type'     => 'color',
                'output'   => array( '.affix .primary-menu ul.nav > li > a:before' ),
                'title'    => __( 'Menu Bar Color', 'growth' ),
                'subtitle' => __( 'Pick a menu active angle color: (default: #FFC576).', 'growth' ),
                'default'  => '#FFC576',
            ),
        ),        
    )
);




Redux::setSection( $opt_name, array(
    'title'            => __( 'Site Header', 'growth' ),
    'id'               => 'site_header',
    'desc'             => __( 'These are site header fields!', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-flag-alt'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Site Header', 'growth' ),
    'id'         => 'site_header_style',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'site_header_background',
            'type'     => 'background',
            'output'   => array( '.header-area' ),
            'title'    => __( 'Header Background', 'growth' ),
            'subtitle' => __( 'Header background with image, color, etc.', 'growth' ),
            'default'   => '#1F2235',
        ),
         array(
            'id'       => 'site_header_overlay',
            'type'     => 'color_rgba',
            'title'    => __( 'Background Overlay Color', 'growth' ),
            'subtitle' => __( 'To set header area background overlay color.', 'growth' ),
            'default'  => array(
                'color' => '#1F2235',
                'alpha' => '.9'
            ),
            'output'   => array( '.header-area:before' ),
            'mode'     => 'background',
            'validate' => 'colorrgba'
        ),
        array(
            'id'             => 'site_header_space',
            'type'           => 'spacing',
            'output'   => array( '.header-area .header-content' ),
            // An array of CSS selectors to apply this font style to
            'mode'           => 'padding',
            // absolute, padding, margin, defaults to padding
            'all'            => false,
            // Have one field that applies to all
            //'top'           => false,     // Disable the top
            'right'         => false,     // Disable the right
            //'bottom'        => false,     // Disable the bottom
            'left'          => false,     // Disable the left
            'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
            'units_extended' => 'true',    // Allow users to select any type of unit
            //'display_units' => 'false',   // Set to false to hide the units if the units are specified
            'title'          => __( 'Header Space', 'growth' ),
            'subtitle'       => __( 'Site Header spacing offset', 'growth' ),
            'desc'           => __( 'To define Top, Right, Bottom, Left padding', 'growth' ),
            'default'        => array(
                'padding-top'    => '150px',
                'padding-bottom' => '150px'
            )
        ),
    ),
) );
Redux::setSection( $opt_name, array(
    'title'            => __( 'Header Title', 'growth' ),
    'id'               => 'site_title',
    'subsection'       => true,
    'customizer_width' => '400px',
    'fields'           => array(
        array(
            'id'       => 'blog_page_title',
            'type'     => 'text',
            'title'    => __( 'Blog Page Title', 'growth' ),
            'subtitle' => __( 'Post list page header title.', 'growth' ),
            'desc'     => __( 'To set blog header title text.', 'growth' ),
            'default'  => 'News Feeds',
        ),
        array(
            'id'       => 'search_page_title',
            'type'     => 'text',
            'title'    => __( 'Search Page Title', 'growth' ),
            'subtitle' => __( 'Search post page header title.', 'growth' ),
            'desc'     => __( 'To set search page header title text.', 'growth' ),
            'default'  => 'Search Results for',
        ),
        array(
            'id'          => 'page_title_typography',
            'type'        => 'typography',
            'title'       => __( 'Page Title Typography', 'growth' ),
            //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
            'google'      => true,
            // Disable google fonts. Won't work if you haven't defined your google api key
            'font-backup' => false,
            // Select a backup non-google font in addition to a google font
            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
            'subsets'       => false, // Only appears if google is true and subsets not set to false
            //'font-size'     => false,
            //'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( '.header-area .page-title' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-title-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'       => 'px',
            // Defaults to px
            'subtitle'    => __( 'Typography option with each property can be called individually.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '600',
                'google'      => true,
                'font-size'   => '40px'
            ),
        ),
        array(
            'id'             => 'page_title_space',
            'type'           => 'spacing',
            'output'   => array( '.header-area .page-title' ),
            // An array of CSS selectors to apply this font style to
            'mode'           => 'margin',
            // absolute, padding, margin, defaults to padding
            'all'            => false,
            // Have one field that applies to all
            //'top'           => false,     // Disable the top
            'right'         => false,     // Disable the right
            //'bottom'        => false,     // Disable the bottom
            'left'          => false,     // Disable the left
            'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
            'units_extended' => 'true',    // Allow users to select any type of unit
            //'display_units' => 'false',   // Set to false to hide the units if the units are specified
            'title'          => __( 'Title Space', 'growth' ),
            'subtitle'       => __( 'Page title spacing.', 'growth' ),
            'desc'           => __( 'You can define spacing Top, Right, Bottom, Left, or Units.', 'growth' ),
            'default'        => array(
                'margin-top'    => '0px',
                'margin-bottom' => '0px'
            )
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'            => __( 'Heder SubTitle', 'growth' ),
    'id'               => 'page_sub_title',
    'subsection'       => true,
    'customizer_width' => '400px',
    'fields'           => array(
        array(
            'id'       => 'sub_title_format',
            'type'     => 'radio',
            'title'    => __( 'Display Format', 'growth' ),
            'subtitle' => __( 'SubTitle format.', 'growth' ),
            'desc'     => __( 'Please select SubTitle display format.', 'growth' ),
            //Must provide key => value pairs for radio options
            'options'  => array(
                '1' => __( 'Site Description' , 'growth' ),
                '2' => __( 'Breadcrumb' , 'growth' ),
                '3' => __( 'Custom Subtitle' , 'growth' ),
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'breadcrumb_home',
            'type'     => 'text',
            'title'    => __( 'Breadcrumb Home', 'growth' ),
            'subtitle' => __( 'Breadcrumbs menu home name.', 'growth' ),
            'desc'     => __( 'To set breadcrumb home text.', 'growth' ),
            'default'  => 'Home',
            'required' => array('sub_title_format','=',2)
        ),
        array(
            'id'       => 'breadcrumb_separator',
            'type'     => 'text',
            'title'    => __( 'Breadcrumb Separator', 'growth' ),
            'subtitle' => __( 'Breadcrumbs menu item separator.', 'growth' ),
            'desc'     => __( 'To set breadcrumb separator.', 'growth' ),
            'default'  => '|',
            'required' => array('sub_title_format','=',2)
        ),        
        array(
            'id'       => 'custom_sub_title',
            'type'     => 'text',
            'title'    => __( 'Custom Subtitle', 'growth' ),
            'subtitle' => __( 'To set custom page subtitle.', 'growth' ),
            'desc'     => __( 'Enter your custom page subtitle.', 'growth' ),
            'default'  => 'Welcome to our website.',
            'required' => array('sub_title_format','=',3)
        ),
        array(
            'id'          => 'page_subtitle_typography',
            'type'        => 'typography',
            'title'       => __( 'Subtitle Typography', 'growth' ),
            //'compiler'      => true,  // Use if you want to hook in your own CSS compiler
            'google'      => true,
            // Disable google fonts. Won't work if you haven't defined your google api key
            'font-backup' => false,
            // Select a backup non-google font in addition to a google font
            'font-style'    => false, // Includes font-style and weight. Can use font-style or font-weight to declare
            'subsets'       => false, // Only appears if google is true and subsets not set to false
            //'font-size'     => false,
            //'line-height'   => false,
            //'word-spacing'  => true,  // Defaults to false
            'letter-spacing'=> true,  // Defaults to false
            //'color'         => false,
            //'preview'       => false, // Disable the previewer
            'all_styles'  => true,
            // Enable all Google Font style/weight variations to be added to the page
            'output'      => array( '.header-area .sub-title, .header-area .sub-title a' ),
            // An array of CSS selectors to apply this font style to dynamically
            'compiler'    => array( 'page-subtitle-compiler' ),
            // An array of CSS selectors to apply this font style to dynamically
            'units'       => 'px',
            // Defaults to px
            'subtitle'    => __( 'Typography option with each property can be called individually.', 'growth' ),
            'default'     => array(
                'color'       => '#ffffff',
                'font-weight'  => '400',
                'google'      => true,
                'font-size'   => '20px',
                'line-height' => '30px'
            ),
        ),
        array(
            'id'             => 'page_subtitle_space',
            'type'           => 'spacing',
            'output'   => array( '.header-area .sub-title' ),
            // An array of CSS selectors to apply this font style to
            'mode'           => 'margin',
            // absolute, padding, margin, defaults to padding
            'all'            => false,
            // Have one field that applies to all
            //'top'           => false,     // Disable the top
            'right'         => false,     // Disable the right
            //'bottom'        => false,     // Disable the bottom
            'left'          => false,     // Disable the left
            'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
            'units_extended' => 'true',    // Allow users to select any type of unit
            //'display_units' => 'false',   // Set to false to hide the units if the units are specified
            'title'          => __( 'Subtitle Space', 'growth' ),
            'subtitle'       => __( 'Allow your users to choose the spacing or margin they want.', 'growth' ),
            'desc'           => __( 'You can enable or disable any piece of this field. Top, Right, Bottom, Left, or Units.', 'growth' ),
            'default'        => array(
                'margin-top'    => '15px',
                'margin-bottom' => '0px'
            )
        ),
    )
) );


Redux::setSection( $opt_name, array(
    'title'            => __( 'Blog Option', 'growth' ),
    'id'               => 'blog_options',
    'desc'             => __( 'You can edit blog all default option.', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-text-width'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Main Blog', 'growth' ),
    'id'         => 'main_blog',
    'subsection' => true,
    'fields'     => array(
         array(
            'id'       => 'main_blog_meta',
            'type'     => 'switch',
            'title'    => __( 'Meta Switch?', 'growth' ),
            'subtitle' => __( 'Turn on to display post meta.', 'growth' ),
            'default'  => true,
        ),
        array(
            'id'       => 'meta_option_select',
            'type'     => 'select',
            'multi'    => true,
            'title'    => __( 'Select Post Meta.', 'growth' ),
            'subtitle' => __( 'Which meta item will be show.', 'growth' ),
            'desc'     => __( 'Please select meta item from here.', 'growth' ),
            //Must provide key => value pairs for radio options
            'options'  => array(
                'author' => __( 'Author', 'growth' ),
                'date' => __( 'Post Date', 'growth' ),
                'comment_count' => __( 'Comment Count', 'growth' ),
                'tags' => __( 'Tags', 'growth' ),
                'category' => __( 'Categories', 'growth' ),
            ),
            'default'  => array( 'date' ),            
            'required' => array( 'main_blog_meta', '=', true )
        ),
         array(
            'id'       => 'main_blog_title',
            'type'     => 'switch',
            'title'    => __( 'Title Switch?', 'growth' ),
            'subtitle' => __( 'Turn on to display post title.', 'growth' ),
            'default'  => true,
        ),
         array(
            'id'       => 'main_blog_thumbnail',
            'type'     => 'switch',
            'title'    => __( 'Show Image?', 'growth' ),
            'subtitle' => __( 'Turn on to display post image.', 'growth' ),
            'default'  => true,
        ),
         array(
            'id'       => 'blog_thumbnail_size',
            'type'     => 'select',
            'title'    => __( 'Thumbnail Size', 'growth' ),
            'options'  => array(
                'thumbnail' => __( 'Thumbnail','growth' ),
                'medium' => __( 'Medium','growth' ),
                'large' => __( 'Large','growth' ),
                'full' => __( 'Full','growth' ),
                'growth-post-image' => __( 'Growth Post Image','growth' ),
            ),
            'default'  => 'growth-post-image',             
            'required' => array( 'main_blog_thumbnail', '=', true )
        ),
         array(
            'id'       => 'blog_content_format',
            'type'     => 'select',
            'title'    => __( 'Content Display', 'growth' ),
            'desc'     => __( 'Controls if the blog content displays an excerpt or full content or is completely disabled for the assigned blog page in "settings > reading" or blog archive pages.', 'growth' ),
            //Must provide key => value pairs for select options
            'options'  => array(
                'excerpt' => __( 'Excerpt','growth' ),
                'full' => __( 'Full Content','growth' ),
                'no_text' => __( 'No Text','growth' ),
            ),
            'default'  => '1'
        ),
        array(
            'id'      => 'content_excerpt_length',
            'type'    => 'spinner',
            'title'   => __( 'Excerpt Length', 'growth' ),
            'desc'    => __( 'Min:10, max: 150, step: 1, default value: 30', 'growth' ),
            'default' => '30',
            'min'     => '10',
            'step'    => '1',
            'max'     => '150',
            'required' => array( 'blog_content_format', '=', 'excerpt' )
        ),
         array(
            'id'       => 'read_more_switch',
            'type'     => 'switch',
            'title'    => __( 'Read More Switch?', 'growth' ),
            'subtitle' => __( 'Turn on to display rede more button.', 'growth' ),
            'default'  => false,
        ),
        array(
            'id'       => 'read_more_text',
            'type'     => 'text',
            'title'    => __( 'Read More Text', 'growth' ),
            'subtitle' => __( 'This is a post read more button text.', 'growth' ),
            'desc'     => __( 'Enter read more button text. HTML tag supported.', 'growth' ),
            'default'  => 'Read More <i class="far fa-long-arrow-alt-right"></i>',
            'required' => array( 'read_more_switch', '=', true )
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Single Blog', 'growth' ),
    'id'         => 'single_blog',
    'subsection' => true,
    'fields'     => array(        
         array(
            'id'       => 'single_blog_meta',
            'type'     => 'switch',
            'title'    => __( 'Meta Switch?', 'growth' ),
            'subtitle' => __( 'Turn on to display post meta.', 'growth' ),
            'default'  => true,
        ),
         array(
            'id'       => 'single_releted_tag',
            'type'     => 'switch',
            'title'    => __( 'Releted Tags?', 'growth' ),
            'subtitle' => __( 'Turn on to display releted tags', 'growth' ),
            'default'  => true,
        ),
         array(
            'id'       => 'single_post_share',
            'type'     => 'switch',
            'title'    => __( 'Social Share Menu?', 'growth' ),
            'subtitle' => __( 'Turn on to display social share menu.', 'growth' ),
            'default'  => false,
        ),
         array(
            'id'       => 'single_post_nav',
            'type'     => 'switch',
            'title'    => __( 'Next Post Navigation?', 'growth' ),
            'subtitle' => __( 'Turn on to display post navigation.', 'growth' ),
            'default'  => true,
        ),        
        array(
            'id'       => 'show_releted_post',
            'type'     => 'switch',
            'title'    => __( 'Releted Post?', 'growth' ),
            'subtitle' => __( 'Turn on to display releted posts.', 'growth' ),
            'default'  => false,
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'            => __( 'Footer Option', 'growth' ),
    'id'               => 'footer_option',
    'desc'             => __( 'You can edit footer all option.', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-list-alt'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Footer Style', 'growth' ),
    'id'         => 'footer_widget_style',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'             => 'footer_top_space',
            'type'           => 'spacing',
            'output'   => array( '.footer-top' ),
            // An array of CSS selectors to apply this font style to
            'mode'           => 'padding',
            // absolute, padding, margin, defaults to padding
            'all'            => false,
            // Have one field that applies to all
            //'top'           => false,     // Disable the top
            //'right'         => false,     // Disable the right
            //'bottom'        => false,     // Disable the bottom
            //'left'          => false,     // Disable the left
            'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
            'units_extended' => 'true',    // Allow users to select any type of unit
            //'display_units' => 'false',   // Set to false to hide the units if the units are specified
            'title'          => __( 'Footer Top Space', 'growth' ),
            'subtitle'       => __( 'To define footer top area space.', 'growth' ),
            'desc'           => __( 'Please set footer top area space.', 'growth' ),
            'default'        => array(
                'padding-top'    => '80px',
                'padding-bottom' => '0px',
                'padding-left' => '0',
                'padding-right' => '0'
            )
        ),
        array(
            'id'       => 'footer_gr_bg',
            'type'     => 'color_gradient',
            'title'    => __( 'Footer Gradient Color Option', 'growth' ),
            'subtitle' => __( 'Only color validation can be done on this field type', 'growth' ),
            'desc'     => __( 'Please select gradient color for footer area.', 'growth' ),
            'default'  => array(
                'from' => '#313552',
                'to'   => '#313552'
            )
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Copyright Option', 'growth' ),
    'id'         => 'copyright_option',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'             => 'footer_bottom_space',
            'type'           => 'spacing',
            'output'   => array( '.footer-bottom' ),
            // An array of CSS selectors to apply this font style to
            'mode'           => 'padding',
            // absolute, padding, margin, defaults to padding
            'all'            => false,
            // Have one field that applies to all
            //'top'           => false,     // Disable the top
            //'right'         => false,     // Disable the right
            //'bottom'        => false,     // Disable the bottom
            //'left'          => false,     // Disable the left
            'units'          => array( 'em', 'px', '%' ),      // You can specify a unit value. Possible: px, em, %
            'units_extended' => 'true',    // Allow users to select any type of unit
            //'display_units' => 'false',   // Set to false to hide the units if the units are specified
            'title'          => __( 'Footer Bottom Space', 'growth' ),
            'subtitle'       => __( 'To define footer bottom area space.', 'growth' ),
            'desc'           => __( 'Please set footer bottom area space.', 'growth' ),
            'default'        => array(
                'padding-top'    => '40px',
                'padding-bottom' => '40px',
                'padding-left' => '0px',
                'padding-right' => '0px'
            )
        ),
         array(
            'id'       => 'copyright_text',
            'type'     => 'editor',
            'title'    => __( 'Copyright Text', 'growth' ),
            'subtitle' => __( 'Please type your copyright text. You can use all HTML tags.', 'growth' ),
            'default'  => __( 'Copyright By@Example - 2019','growth' ),
        ),
        array(
            'id'       => 'copyright_typography',
            'type'     => 'typography',
            'title'    => __( 'Copyright Typography', 'growth' ),
            'subtitle' => __( 'To change copyright text typography.', 'growth' ),
            'google'   => true,
            'output' => array('.copyright_text'),
            'default'  => array(
                'color'       => '#ffffff',
                'font-size'   => '16px',
                'font-weight' => 'Normal',
            ),
        ),
    )
) );

Redux::setSection( $opt_name, array(
    'title'            => __( '404 page', 'growth' ),
    'id'               => 'error_page_option',
    'desc'             => __( 'You can edit error page option.', 'growth' ),
    'customizer_width' => '400px',
    'icon'             => 'el el-info-circle'
) );

Redux::setSection( $opt_name, array(
    'title'      => __( 'Error Option', 'growth' ),
    'id'         => 'error_option',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'error_image',
            'type'     => 'media',
            'url'      => true,
            'title'    => __( '404 Image', 'growth' ),
            'compiler' => 'true',
            'subtitle' => __( 'Error page side image.', 'growth' ),
            'default'  => array( 'url' => get_theme_file_uri('assets/images/error-image.png') ),
        ),
        array(
            'id'       => 'error_title',
            'type'     => 'text',
            'title'    => __( 'Title', 'growth' ),
            'default'  => 'Error',
        ),
        array(
            'id'       => 'error_subtitle',
            'type'     => 'text',
            'title'    => __( 'Sub Title', 'growth' ),
            'default'  => 'Oops! Page Not Found.',
        ),
        array(         
            'id'       => 'error_page_background',
            'type'     => 'background',
            'output'      => array( '.error-area' ),
            'title'    => __('Error Background', 'growth'),
            'subtitle' => __('Error background with image, color, etc.', 'growth'),
            'default'  => array(
                'background-color' => '',
                'background-image' => get_theme_file_uri('assets/images/error-bg.png'),
                'background-position' => 'left center',
                'background-repeat' => 'no-repeat',
                'background-size' => 'contain',
                'background-attachment' => 'scroll',
            )
        ),
        array(
            'id'       => 'error_title_color',
            'type'     => 'color',
            'output'   => array( '.error-area .big-text' ),
            'title'    => __( 'Error Title Color', 'growth' ),
            'subtitle' => __( 'Pick a title color for the 404 (default: #ffc576).', 'growth' ),
            'default'  => '#ffffff',
        ),
        array(
            'id'       => 'error_subtitle_color',
            'type'     => 'color',
            'output'   => array( '.error-area .medium-text' ),
            'title'    => __( 'Error Sub Title Color', 'growth' ),
            'subtitle' => __( 'Pick a sub title color for the 404 (default: #ffffff).', 'growth' ),
            'default'  => '#ffffff',
        ),
        array(
            'id'       => 'error_button_color',
            'type'     => 'color',
            'output'   => array( '.error-area .error-button' ),
            'title'    => __( 'Error Button Color', 'growth' ),
            'subtitle' => __( 'Pick a button color for the 404 (default: #1F2235).', 'growth' ),
            'default'  => '#1F2235',
        ),
        array(
            'id'       => 'error_button_hover_color',
            'type'     => 'color',
            'output'   => array( '.error-area .error-button:hover' ),
            'title'    => __( 'Error Button Color', 'growth' ),
            'subtitle' => __( 'Pick a button color for the 404 (default: #1F2235).', 'growth' ),
            'default'  => '#ffc576',
        ),
        array(         
            'id'       => 'error_button_background',
            'type'     => 'background',
            'background-repeat'     => false,
            'background-attachment'     => false,
            'background-position'     => false,
            'background-image'     => false,
            'background-size'     => false,
            'output'      => array( '.error-area .error-button' ),
            'title'    => __('Button Background', 'growth'),
            'subtitle' => __('Error button background color select form here.', 'growth'),
            'default'  => array(
                'background-color' => '#ffc576',
            )
        ),
        array(         
            'id'       => 'error_button_hover_background',
            'type'     => 'background',
            'background-repeat'     => false,
            'background-attachment'     => false,
            'background-position'     => false,
            'background-image'     => false,
            'background-size'     => false,
            'output'      => array( '.error-area .error-button:hover' ),
            'title'    => __('Hover Background', 'growth'),
            'subtitle' => __('Error button hover background color select form here.', 'growth'),
            'default'  => array(
                'background-color' => '#ffffff',
            )
        ),
         array(
            'id'       => 'error_button_border',
            'type'     => 'border',
            'title'    => __( 'Button Border', 'growth' ),
            'subtitle' => __( 'Only color validation can be done on this field type', 'growth' ),
            'output'   => array( '.error-area .error-button' ),
            'default'  => array(
                'border-color'  => '#ffc576',
                'border-style'  => 'solid',
                'border-top'    => '1px',
                'border-right'  => '1px',
                'border-bottom' => '1px',
                'border-left'   => '1px'
            ),
        ),
    )
) );
